@@ -11,9 +11,9 @@ from imswitch.imcommon.model import initLogger
 
 
 class PixelCalibrationManager(SignalInterface):
-    sigPixelCalibrationMaskUpdated = Signal(object)  # (maskCombined)
 
     def __init__(self, PixelCalibrationInfo, *args, **kwargs):
+        self.sigPixelCalibrationMaskUpdated = Signal(object)  # (maskCombined)  # (maskCombined)
         super().__init__(*args, **kwargs)
         self.__logger = initLogger(self)
 
